<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CommandLineFocus</name>
    <message>
        <location filename="../CommandLineFocusInit.js" line="+2"/>
        <source>&amp;Focus on Command Line</source>
        <translation>Vai alla riga di comando</translation>
    </message>
</context>
</TS>
